@@ -3,7 +3,6 @@
   ##########################
 
 
- is.Gram <- function(x){
-   aux<-ifelse(class(x)=="Gram",TRUE,FALSE)
-   return(aux)
- }
\ No newline at end of file
+is.Gram <- function(x){
+	return(inherits(x,"Gram"))
+	}
\ No newline at end of file
