@@ -16,17 +16,17 @@ z_to_dist <- function(z,metric){
  
    # see if z is a distance object or have a explanatory variables
    # (in this case compute the distance matrix with daisy)
-   if (class(z)[1]=="dist"||class(z)[1]=="dissimilarity"||class(z)[1]=="D2") {
-     D<-z
-     way<-"D2"
-   }else{
+   if (inherits(z,"dist")||inherits(z,"dissimilarity")||inherits(z,"D2")) {
+		D<-z
+		way<-"D2"
+		}else{
      # z must be matrix or data.frame
      if (is.numeric(z))
        z<-as.matrix(z)
      if (is.factor(z))
        z<-data.frame(z)
 
-     if (class(z)!="data.frame"&&class(z)!="matrix")
+     if (!inherits(z,"data.frame")&&!inherits(z,"matrix"))
         stop("'z' must be matrix/data.frame or a numeric vector")
      else {
 
